@@ -63,6 +63,14 @@ public final class GVWPDepotList
         addConstraint("maxentries","maxentries","", LogFilter.FILTER_NONE);
     }
     
+    /**
+     * @see org.kapott.hbci.GV.HBCIJobImpl#redoAllowed()
+     */
+    @Override
+    protected boolean redoAllowed()
+    {
+        return true;
+    }
     
     protected void extractResults(HBCIMsgStatus msgstatus,String header,int idx) 
     {
