@@ -23,7 +23,6 @@ package org.kapott.hbci.manager;
 
 import java.lang.reflect.Constructor;
 import java.security.KeyPair;
-import java.util.Date;
 import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.List;
@@ -141,125 +140,11 @@ public final class HBCIHandler
         } catch (Exception e) {
             throw new HBCI_Exception(HBCIUtilsInternal.getLocMsg("EXCMSG_CANT_CREATE_HANDLE"),e);
         }
-        
-        // wenn in den UPD noch keine SEPA- und TAN-Medien-Informationen ueber die Konten enthalten
-        // sind, versuchen wir, diese zu holen
-        Properties upd=passport.getUPD();
-        if (upd!=null && !upd.containsKey("_fetchedMetaInfo"))
-        {
-        	// wir haben UPD, in denen aber nicht "_fetchedMetaInfo" drinsteht
-        	updateMetaInfo();
-        }
     }
     
     /**
-     * Ruft die SEPA-Infos der Konten sowie die TAN-Medienbezeichnungen ab.
-     * unterstuetzt wird und speichert diese Infos in den UPD.
+     * Macht die anonyme Initialisierung und ruft die BPD ab.
      */
-    public void updateMetaInfo()
-    {
-        Properties bpd = passport.getBPD();
-        if (bpd == null)
-        {
-          HBCIUtils.log("have no bpd, skip fetching of meta info", HBCIUtils.LOG_WARN);
-          return;
-        }
-
-        try
-        {
-            final Properties lowlevel = this.getSupportedLowlevelJobs();
-            
-            // SEPA-Infos abrufen
-            if (lowlevel.getProperty("SEPAInfo") != null)
-            {
-                HBCIUtils.log("fetching SEPA information", HBCIUtils.LOG_INFO);
-                HBCIJob sepainfo = this.newJob("SEPAInfo");
-                sepainfo.addToQueue();
-            }
-
-            // TAN-Medien abrufen - aber nur bei PIN/TAN-Verfahren
-            if (lowlevel.getProperty("TANMediaList") != null && (this.passport instanceof AbstractPinTanPassport))
-            {
-                HBCIUtils.log("fetching TAN media list", HBCIUtils.LOG_INFO);
-                HBCIJob tanMedia = this.newJob("TANMediaList");
-                tanMedia.addToQueue();
-            }
-
-            HBCIExecStatus status = this.execute();
-            if (status.isOK())
-            {
-                HBCIUtils.log("successfully fetched meta info", HBCIUtils.LOG_INFO);
-                passport.getUPD().setProperty("_fetchedMetaInfo",new Date().toString());
-                passport.saveChanges();
-            }
-            else
-            {
-                HBCIUtils.log("error while fetching meta info: " + status.toString(), HBCIUtils.LOG_ERR);
-            }
-        }
-        catch (Exception e)
-        {
-            // Wir werfen das nicht als Exception. Unschoen, wenn das nicht klappt.
-            // Aber kein Grund zur Panik.
-            HBCIUtils.log(e);
-        }
-    }
-
-    
-    /**
-     * Wenn der GV SEPAInfo unterstützt wird, heißt das, dass die Bank mit
-     * SEPA-Konten umgehen kann. In diesem Fall holen wir die SEPA-Informationen
-     * über die Konten von der Bank ab - für jedes SEPA-fähige Konto werden u.a. 
-     * BIC/IBAN geliefert
-     * @deprecated Bitte <code>updateMetaInfo</code> verwenden. Das aktualisiert auch die TAN-Medien.
-     */
-    public void updateSEPAInfo()
-    {
-        Properties bpd = passport.getBPD();
-        if (bpd == null)
-        {
-          HBCIUtils.log("have no bpd, skipping SEPA information fetching", HBCIUtils.LOG_WARN);
-          return;
-        }
-
-        // jetzt noch zusaetzliche die SEPA-Informationen abholen
-        try {
-        	if (getSupportedLowlevelJobs().getProperty("SEPAInfo")!=null) {
-        		HBCIUtils.log("trying to fetch SEPA information from institute", HBCIUtils.LOG_INFO);
-        		
-        		// HKSPA wird unterstuetzt
-        		HBCIJob sepainfo=newJob("SEPAInfo");
-        		sepainfo.addToQueue();
-        		HBCIExecStatus status=execute();
-        		if (status.isOK()) {
-        			HBCIUtils.log("successfully fetched information about SEPA accounts from institute", HBCIUtils.LOG_INFO);
-        			
-        			passport.getUPD().setProperty("_fetchedSEPA","1");
-        			passport.saveChanges();
-        		} else {
-        			HBCIUtils.log("error while fetching information about SEPA accounts from institute:", HBCIUtils.LOG_ERR);
-        			HBCIUtils.log(status.toString(), HBCIUtils.LOG_ERR);
-        		}
-        		/* beim execute() werden die Job-Result-Objekte automatisch
-        		 * gefuellt. Der GV-Klasse fuer SEPAInfo haengt sich in diese
-        		 * Logik rein, um gleich die UPD mit den SEPA-Konto-Daten
-        		 * zu aktualisieren, so dass an dieser Stelle die UPD um
-        		 * die SEPA-Informationen erweitert wurden. 
-        		 */
-        	} else {
-        		HBCIUtils.log("institute does not support SEPA accounts, so we skip fetching information about SEPA", HBCIUtils.LOG_DEBUG);
-        	}
-        }
-        catch (HBCI_Exception he)
-        {
-          throw he;
-        }
-        catch (Exception e)
-        {
-        	throw new HBCI_Exception(e);
-        }
-    }
-    
     private void registerInstitute()
     {
         try {
@@ -271,6 +156,9 @@ public final class HBCIHandler
         }
     }
 
+    /**
+     * Ruft die UPD ab.
+     */
     private void registerUser()
     {
         try {
@@ -282,6 +170,18 @@ public final class HBCIHandler
         }
     }
 
+    /**
+     * @see org.kapott.hbci.manager.IHandlerData#sync(boolean)
+     */
+    public void sync(boolean force)
+    {
+      HBCIInstitute inst = new HBCIInstitute(kernel,passport,false);
+      inst.sync(force);
+      
+      HBCIUser user = new HBCIUser(kernel,passport,false);
+      user.sync(force);
+    }
+    
     /** <p>Schließen des Handlers. Diese Methode sollte immer dann aufgerufen werden,
         wenn die entsprechende HBCI-Verbindung nicht mehr benötigt wird. </p><p>
         Beim Schließen des Handlers wird das Passport ebenfalls geschlossen.
@@ -418,9 +318,9 @@ public final class HBCIHandler
         
         customerId=fixUnspecifiedCustomerId(customerId);
         
-        HBCIDialog dialog=null;
+        HBCIDialog dialog = null;
         try {
-            dialog=getDialogFor(customerId);
+            dialog = getDialogFor(customerId);
             dialog.addTask((HBCIJobImpl)job);
         } finally {
             // wenn beim hinzufügen des jobs ein fehler auftrat, und wenn der
@@ -429,7 +329,8 @@ public final class HBCIHandler
             // auszuführender dialoge entfernt werden
             
             if (dialog!=null) {
-                if (dialog.getAllTasks().size()==0) {
+                if (dialog.getMessageQueue().getTaskCount() == 0)
+                {
                     HBCIUtils.log("removing empty dialog for customerid "+customerId+" from list of dialogs",HBCIUtils.LOG_DEBUG);
                     dialogs.remove(customerId);
                 }
