@@ -837,7 +837,7 @@ public final class HBCIUtils
 
 			refreshBLZList(HBCIUtils.class.getClassLoader());
 
-			if (Security.getProvider("CryptAlgs4Java") == null)
+			if (Security.getProvider(CryptAlgs4JavaProvider.NAME) == null)
 			{
 				Security.addProvider(new CryptAlgs4JavaProvider());
 			}
@@ -2230,7 +2230,7 @@ public final class HBCIUtils
 		// Im Zweifel lassen wir die Bankverbindung lieber durch
 		if (alg == null || alg.length() != 2)
 		{
-			HBCIUtils.log("no crc information about " + blz + " in database", HBCIUtils.LOG_WARN);
+			HBCIUtils.log("no crc information about " + blz + " in database", HBCIUtils.LOG_DEBUG);
 			return true;
 		}
 
