@@ -33,15 +33,15 @@ import java.util.Properties;
 import org.kapott.hbci.callback.HBCICallback;
 import org.kapott.hbci.comm.Comm;
 import org.kapott.hbci.comm.Filter;
+import org.kapott.hbci.dialog.DialogContext;
+import org.kapott.hbci.dialog.DialogEvent;
 import org.kapott.hbci.exceptions.HBCI_Exception;
 import org.kapott.hbci.exceptions.InvalidUserDataException;
-import org.kapott.hbci.manager.HBCIDialog;
 import org.kapott.hbci.manager.HBCIKey;
 import org.kapott.hbci.manager.HBCIUtils;
 import org.kapott.hbci.manager.HBCIUtilsInternal;
 import org.kapott.hbci.manager.IHandlerData;
 import org.kapott.hbci.manager.LogFilter;
-import org.kapott.hbci.status.HBCIMsgStatus;
 import org.kapott.hbci.structures.Konto;
 import org.kapott.hbci.structures.Limit;
 import org.kapott.hbci.structures.Value;
@@ -178,7 +178,7 @@ public abstract class AbstractHBCIPassport
         return comm;
     }
     
-    protected abstract Comm getCommInstance();
+    public abstract Comm getCommInstance();
     
     public final Filter getCommFilter()
     {
@@ -276,33 +276,36 @@ public abstract class AbstractHBCIPassport
         return ret.toArray(new Konto[ret.size()]);
     }
     
+    /**
+     * @see org.kapott.hbci.passport.HBCIPassport#fillAccountInfo(org.kapott.hbci.structures.Konto)
+     */
     public final void fillAccountInfo(Konto account)
     {
-        String  number=HBCIUtilsInternal.stripLeadingZeroes(account.number);
-        String  iban=HBCIUtilsInternal.stripLeadingZeroes(account.iban);
-        boolean haveNumber=(number!=null && number.length()!=0);
-        boolean haveIBAN=(iban!=null && iban.length()!=0);
+        String  number     = HBCIUtilsInternal.stripLeadingZeroes(account.number);
+        String  iban       = HBCIUtilsInternal.stripLeadingZeroes(account.iban);
+        boolean haveNumber = (number!=null && number.length()!=0);
+        boolean haveIBAN   = (iban!=null && iban.length()!=0);
         
-        Konto[] accounts=getAccounts();
+        Konto[] accounts = getAccounts();
         
-        for (int i=0;i<accounts.length;i++) {
-            String temp_number=HBCIUtilsInternal.stripLeadingZeroes(accounts[i].number);
-            String temp_iban=HBCIUtilsInternal.stripLeadingZeroes(accounts[i].iban);
+        for (int i=0;i<accounts.length;i++)
+        {
+            String temp_number = HBCIUtilsInternal.stripLeadingZeroes(accounts[i].number);
+            String temp_iban = HBCIUtilsInternal.stripLeadingZeroes(accounts[i].iban);
             
-            if (haveNumber && number.equals(temp_number) ||
-                    haveIBAN && iban.equals(temp_iban)) 
+            if (haveNumber && number.equals(temp_number) || haveIBAN && iban.equals(temp_iban)) 
             {
-                account.blz=accounts[i].blz;
-                account.country=accounts[i].country;
-                account.number=accounts[i].number;
-                account.subnumber=accounts[i].subnumber;
-                account.type=accounts[i].type;
-                account.curr=accounts[i].curr;
-                account.customerid=accounts[i].customerid;
-                account.name=accounts[i].name;
-                account.bic=accounts[i].bic;
-                account.iban=accounts[i].iban;
-                account.acctype=accounts[i].acctype;
+                if (accounts[i].blz != null        && accounts[i].blz.length() > 0)        account.blz=accounts[i].blz;
+                if (accounts[i].country != null    && accounts[i].country.length() > 0)    account.country=accounts[i].country;
+                if (accounts[i].number != null     && accounts[i].number.length() > 0)     account.number=accounts[i].number;
+                if (accounts[i].subnumber != null  && accounts[i].subnumber.length() > 0)  account.subnumber=accounts[i].subnumber;
+                if (accounts[i].type != null       && accounts[i].type.length() > 0)       account.type=accounts[i].type;
+                if (accounts[i].curr != null       && accounts[i].curr.length() > 0)       account.curr=accounts[i].curr;
+                if (accounts[i].customerid != null && accounts[i].customerid.length() > 0) account.customerid=accounts[i].customerid;
+                if (accounts[i].name != null       && accounts[i].name.length() > 0)       account.name=accounts[i].name;
+                if (accounts[i].bic != null        && accounts[i].bic.length() > 0)        account.bic=accounts[i].bic;
+                if (accounts[i].iban != null       && accounts[i].iban.length() > 0)       account.iban=accounts[i].iban;
+                if (accounts[i].acctype != null    && accounts[i].acctype.length() > 0)    account.acctype=accounts[i].acctype;
                 break;
             }
         }
@@ -954,24 +957,20 @@ public abstract class AbstractHBCIPassport
         
         return result;
     }
-
-    public boolean postInitResponseHook(HBCIMsgStatus msgStatus, boolean anonDialog)
+    
+    /**
+     * @see org.kapott.hbci.passport.HBCIPassportInternal#onDialogEvent(org.kapott.hbci.dialog.DialogEvent, org.kapott.hbci.dialog.DialogContext)
+     */
+    @Override
+    public void onDialogEvent(DialogEvent event, DialogContext ctx)
     {
-        // die default-Implementierung tut nichts und verlangt auch keine
-        // erneute Dialog-Initialisierung
-        return false;
+        // Default-Implementierung macht nichts.
     }
 
-    public void beforeCustomDialogHook(HBCIDialog dialog)
-    {
-        // default implementation does nothing
-    }
-    
-    public void afterCustomDialogInitHook(HBCIDialog dialog)
-    {
-        // default implementation does nothing - only PinTan variant will override this
-    }
-    
+    /**
+     * @see org.kapott.hbci.passport.HBCIPassportInternal#getMaxGVSegsPerMsg()
+     */
+    @Override
     public int getMaxGVSegsPerMsg()
     {
         return 0;
