@@ -36,9 +36,9 @@ import org.kapott.hbci.manager.HHDVersion.Type;
 import org.kapott.hbci.manager.LogFilter;
 import org.kapott.hbci.manager.MatrixCode;
 import org.kapott.hbci.manager.QRCode;
+import org.kapott.hbci.manager.TanMethod;
 import org.kapott.hbci.passport.storage.PassportData;
 import org.kapott.hbci.passport.storage.PassportStorage;
-import org.kapott.hbci.security.Sig;
 
 /** <p>Passport-Klasse für HBCI mit PIN/TAN. Dieses Sicherheitsverfahren wird erst
     in FinTS 3.0 spezifiziert, von einigen Banken aber schon mit früheren HBCI-Versionen
@@ -84,10 +84,12 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
         this(initObject,0);
 
         String  header="client.passport.PinTan.";
-        String  fname=HBCIUtils.getParam(header+"filename");
-        boolean init=HBCIUtils.getParam(header+"init","1").equals("1");
         
-        setFileName(fname);
+        String filename = HBCIUtils.getParam(header+"filename");
+        if (initObject instanceof File)
+            filename = ((File) initObject).getAbsolutePath();
+        
+        this.setFileName(filename);
         setCertFile(HBCIUtils.getParam(header+"certfile"));
         setCheckCert(HBCIUtils.getParam(header+"checkcert","1").equals("1"));
         
@@ -95,6 +97,7 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
         setProxyUser(HBCIUtils.getParam(header+"proxyuser",""));
         setProxyPass(HBCIUtils.getParam(header+"proxypass",""));
 
+        boolean init=HBCIUtils.getParam(header+"init","1").equals("1");
         if (init)
         {
             this.read();
@@ -206,9 +209,21 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
             HBCIUtils.log("saving two step mechs: " + l, HBCIUtils.LOG_DEBUG);
             data.twostepMechs = l;
             
-            final String s = this.getCurrentTANMethod(false);
-            HBCIUtils.log("saving current tan method: "+s, HBCIUtils.LOG_DEBUG);
-            data.tanMethod = s;
+            try
+            {
+                final String s = this.getCurrentTANMethod(false);
+                HBCIUtils.log("saving current tan method: "+s, HBCIUtils.LOG_DEBUG);
+                data.tanMethod = s;
+            }
+            catch (Exception e)
+            {
+                // Nur zur Sicherheit. In der obigen Funktion werden u.U. eine Menge Sachen losgetreten.
+                // Wenn da irgendwas schief laeuft, soll deswegen nicht gleich das Speichern der Config
+                // scheitern. Im Zweifel speichern wir dann halt das ausgewaehlte Verfahren erstmal nicht
+                // und der User muss es beim naechsten Mal neu waehlen
+                HBCIUtils.log("could not determine current tan methode, skipping: " + e.getMessage(),HBCIUtils.LOG_DEBUG);
+                HBCIUtils.log(e,HBCIUtils.LOG_DEBUG2);
+            }
 
             PassportStorage.save(this,data,new File(this.getFileName()));
         }
@@ -266,7 +281,7 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
             
             String pintanMethod=getCurrentTANMethod(false);
 
-            if (pintanMethod.equals(Sig.SECFUNC_SIG_PT_1STEP)) {
+            if (pintanMethod.equals(TanMethod.ONESTEP.getId())) {
                 // nur beim normalen einschritt-verfahren muss anhand der segment-
                 // codes ermittelt werden, ob eine tan benötigt wird
                 HBCIUtils.log("onestep method - checking GVs to decide whether or not we need a TAN",HBCIUtils.LOG_DEBUG);
@@ -321,14 +336,22 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
                     }
                 }
             } else {
+
                 HBCIUtils.log("twostep method - checking passport(challenge) to decide whether or not we need a TAN",HBCIUtils.LOG_DEBUG);
                 Properties secmechInfo=getCurrentSecMechInfo();
-                
+
+                String haveSCA = (String) getPersistentData(KEY_PD_SCA);
+                setPersistentData(KEY_PD_SCA,null);
+
                 // gespeicherte challenge aus passport holen
-                String challenge=(String)getPersistentData("pintan_challenge");
-                setPersistentData("pintan_challenge",null);
+                String challenge=(String)getPersistentData(KEY_PD_CHALLENGE);
+                setPersistentData(KEY_PD_CHALLENGE,null);
                 
-                if (challenge==null)
+                if (haveSCA != null)
+                {
+                    HBCIUtils.log("will not sign with a TAN, found status code 3076, no SCA required",HBCIUtils.LOG_DEBUG);
+                }
+                else if (challenge==null) // manche Banken senden auch "nochallenge" *facepalm*
                 {
                     // es gibt noch keine challenge
                     HBCIUtils.log("will not sign with a TAN, because there is no challenge",HBCIUtils.LOG_DEBUG);
@@ -338,8 +361,8 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
                     HBCIUtils.log("found challenge in passport, so we ask for a TAN",HBCIUtils.LOG_DEBUG);
                     
                     // willuhn 2011-05-27 Wir versuchen, den Flickercode zu ermitteln und zu parsen
-                    String hhduc = (String) getPersistentData("pintan_challenge_hhd_uc");
-                    setPersistentData("pintan_challenge_hhd_uc",null); // gleich wieder aus dem Passport loeschen
+                    String hhduc = (String) getPersistentData(KEY_PD_HHDUC);
+                    setPersistentData(KEY_PD_HHDUC,null); // gleich wieder aus dem Passport loeschen
 
                     HHDVersion hhd = HHDVersion.find(secmechInfo);
                     HBCIUtils.log("detected HHD version: " + hhd,HBCIUtils.LOG_DEBUG);
@@ -368,7 +391,7 @@ public class HBCIPassportPinTan extends AbstractPinTanPassport
                     }
                     else
                     {
-                        FlickerCode flicker = FlickerCode.tryParse(challenge,hhduc);
+                        FlickerCode flicker = FlickerCode.tryParse(hhd,challenge,hhduc);
                         if (flicker != null)
                         {
                             // Bei chipTAN liefern wir den bereits geparsten und gerenderten Flickercode
